==> kuflow-robotframework-0.2.0.tar.gz: kuflow-robotframework-0.2.0/src/kuflow_rest_client/models/__init__.py <==
# coding: utf-8
#
# MIT License
#
# Copyright (c) 2022 KuFlow
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.#



# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from kuflow_rest_client.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from kuflow_rest_client.model.abstract_audited import AbstractAudited
from kuflow_rest_client.model.default_error import DefaultError
from kuflow_rest_client.model.default_error_info import DefaultErrorInfo
from kuflow_rest_client.model.delete_element_command import DeleteElementCommand
from kuflow_rest_client.model.delete_element_document_command import (
    DeleteElementDocumentCommand,
)
from kuflow_rest_client.model.element_value_document import ElementValueDocument
from kuflow_rest_client.model.element_value_or_array_value import (
    ElementValueOrArrayValue,
)
from kuflow_rest_client.model.log import Log
from kuflow_rest_client.model.log_level import LogLevel
from kuflow_rest_client.model.principal import Principal
from kuflow_rest_client.model.principal_type import PrincipalType
from kuflow_rest_client.model.task import Task
from kuflow_rest_client.model.task_all_of import TaskAllOf
from kuflow_rest_client.model.task_element_value import TaskElementValue
from kuflow_rest_client.model.task_state import TaskState
from kuflow_rest_client.model.tasks_definition_summary import TasksDefinitionSummary

==> kuflow-robotframework-0.3.0.tar.gz: kuflow-robotframework-0.3.0/src/kuflow_rest_client/models/__init__.py <==
# coding: utf-8
#
# MIT License
#
# Copyright (c) 2022 KuFlow
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.#


# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from kuflow_rest_client.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from kuflow_rest_client.model.abstract_audited import AbstractAudited
from kuflow_rest_client.model.default_error import DefaultError
from kuflow_rest_client.model.default_error_info import DefaultErrorInfo
from kuflow_rest_client.model.delete_element_command import DeleteElementCommand
from kuflow_rest_client.model.delete_element_value_document_command import (
    DeleteElementValueDocumentCommand,
)
from kuflow_rest_client.model.log import Log
from kuflow_rest_client.model.log_level import LogLevel
from kuflow_rest_client.model.principal import Principal
from kuflow_rest_client.model.principal_type import PrincipalType
from kuflow_rest_client.model.task import Task
from kuflow_rest_client.model.task_element_value import TaskElementValue
from kuflow_rest_client.model.task_element_value_document import (
    TaskElementValueDocument,
)
from kuflow_rest_client.model.task_element_value_document_item import (
    TaskElementValueDocumentItem,
)
from kuflow_rest_client.model.task_element_value_number import TaskElementValueNumber
from kuflow_rest_client.model.task_element_value_object import TaskElementValueObject
from kuflow_rest_client.model.task_element_value_or_array_value import (
    TaskElementValueOrArrayValue,
)
from kuflow_rest_client.model.task_element_value_principal import (
    TaskElementValuePrincipal,
)
from kuflow_rest_client.model.task_element_value_principal_item import (
    TaskElementValuePrincipalItem,
)
from kuflow_rest_client.model.task_element_value_string import TaskElementValueString
from kuflow_rest_client.model.task_element_value_type import TaskElementValueType
from kuflow_rest_client.model.task_state import TaskState
from kuflow_rest_client.model.tasks_definition_summary import TasksDefinitionSummary
